@@ -9,10 +9,10 @@
 #include <valarray>
 #include <algorithm>
 
-extern "C" {
+//extern "C" {
 #include <R.h>
 #include <Rmath.h>
-};
+//};
 
 #include "global.h"
 #include "Node.h"
